@@ -58,7 +58,8 @@ def ducat_info(item_name, wfcd_api):
 def vaulted_info(item_name, wfcd_api):
     if item_name in wfcd_api:
         if 'vaulted' in wfcd_api[item_name]:
-            return wfcd_api[item_name]['vaulted']
+            if 'tags' not in wfcd_api[item_name] or 'Never Vaulted' not in wfcd_api[item_name]['tags']:
+                return wfcd_api[item_name]['vaulted']
 
     return False
 
@@ -394,7 +395,7 @@ def build_json_files():
     set_data = build_set_data(relic_list)
     relic_data = build_relic_data(relic_list, set_data)
 
-    return json.loads(json.dumps(relic_data)), json.loads(json.dumps(set_data))
+    return json.loads(json.dumps(relic_data)), json.loads(json.dumps(set_data)), json.loads(json.dumps(relic_list))
 
 
 def get_price_data():
